@@ -33,7 +33,10 @@ Algorithm::SVM::DataSet is a representation of the datasets passed to
 Algorithm::SVM object for training or classification.  Each dataset has
 an associated label, which classifies it as being part of a specific group.
 A dataset object also has one or more key/value pairs corresponding to
-the attributes that will be used for classification.
+the attributes that will be used for classification. Values equal
+to zero will not be stored, and are returned by default if no
+key/value pair exists. This sparse format saves memory, and is
+treated in exactly the same way by libsvm.
 
 =head1 CONSTRUCTORS
 
@@ -66,9 +69,20 @@ value is provided, the method will return the corresponding value.  If
 two value are provided, the method will set the first parameter to the
 value of the second.
 
+
+  $ds->asArray();
+
+
+The asArray method returns the contents of a DataSet object in
+an efficient way. An optional parameter, $numAttr, can be used to
+pad the array with zeros if the number of attributes is not known
+from the beginning (e.g. when creating a word vector on the fly,
+since all keys not given are automatically assumed to be zero)
+
 =head1 MAINTAINER
 
 Matthew Laird <matt@brinkman.mbb.sfu.ca>
+Alexander K. Seewald <alex@seewald.at>
 
 =head1 SEE ALSO
 
@@ -104,10 +118,36 @@ sub attribute {
   my ($self, $key, $val) = @_;
 
   croak("No key specified") if(! defined($key));
+  croak("Negative key specified") if (int($key)<0);
 
-  return(defined($val)) ? _setAttribute($self, int($key), $val + 0) :  _getAttribute($self, int($key));
+  if (defined($val)) {
+		return _setAttribute($self, int($key), $val + 0);
+  } else {
+		return _getAttribute($self, int($key));
+	}
 }
 
+sub asArray {
+	my ($self,$numAttr) = @_;
+
+  if (!defined($numAttr)) { $numAttr=_getMaxI($self)+1; }
+  my @x=(); for (my $i=0; $i<$numAttr; $i++) { push @x,0; }
+  
+  my $i=0; my $k; my $v;
+	$k=_getIndexAt($self,$i);
+  $v=_getValueAt($self,$i);
+	while ($k!=-1 && $k<$numAttr) {
+    $x[$k]=$v;
+    $i++;
+		$k=_getIndexAt($self,$i);
+  	$v=_getValueAt($self,$i);
+  };
+
+  return @x;
+}
+		
+
+
 1;
 
 __END__
